@@ -21,6 +21,8 @@ var keycodes = {
 	'ONE': '49',
 	'TWO': '50',
 	'THREE': '51',
+	'FOUR': '52',
+	'FIVE': '53',
 	'h' : '72',
 	'T' : '84',
 	'F' : '70',
