@@ -19,6 +19,7 @@
 
 """Virtual memory plugin."""
 
+from glances.compat import iterkeys
 from glances.plugins.glances_plugin import GlancesPlugin
 
 import psutil
@@ -60,7 +61,7 @@ class Plugin(GlancesPlugin):
 
     def __init__(self, args=None):
         """Init the plugin."""
-        GlancesPlugin.__init__(self, args=args, items_history_list=items_history_list)
+        super(Plugin, self).__init__(args=args, items_history_list=items_history_list)
 
         # We want to display the stat in the curse interface
         self.display_curse = True
@@ -139,7 +140,7 @@ class Plugin(GlancesPlugin):
                     self.reset()
                     return self.stats
 
-                for key in list(self.stats.keys()):
+                for key in iterkeys(self.stats):
                     if self.stats[key] != '':
                         self.stats[key] = float(self.stats[key]) * 1024
 
@@ -163,7 +164,7 @@ class Plugin(GlancesPlugin):
     def update_views(self):
         """Update stats views."""
         # Call the father's method
-        GlancesPlugin.update_views(self)
+        super(Plugin, self).update_views()
 
         # Add specifics informations
         # Alert and log
