@@ -19,8 +19,7 @@
 
 """Process count plugin."""
 
-# Import Glances libs
-from glances.core.glances_processes import glances_processes
+from glances.processes import glances_processes
 from glances.plugins.glances_plugin import GlancesPlugin
 
 # Note: history items list is not compliant with process count
@@ -36,7 +35,7 @@ class Plugin(GlancesPlugin):
 
     def __init__(self, args=None):
         """Init the plugin."""
-        GlancesPlugin.__init__(self, args=args)
+        super(Plugin, self).__init__(args=args)
 
         # We want to display the stat in the curse interface
         self.display_curse = True
@@ -86,7 +85,7 @@ class Plugin(GlancesPlugin):
             ret.append(self.curse_add_line(msg, "TITLE"))
             msg = ' {0} '.format(glances_processes.process_filter)
             ret.append(self.curse_add_line(msg, "FILTER"))
-            msg = '(press ENTER to edit)'
+            msg = '(\'ENTER\' to edit, \'E\' to reset)'
             ret.append(self.curse_add_line(msg))
             ret.append(self.curse_new_line())
 
