@@ -19,24 +19,20 @@
 
 """Process list plugin."""
 
-# Import sys libs
 import operator
 import os
 from datetime import timedelta
 
-# Import Glances libs
-from glances.core.glances_logging import logger
+from glances.compat import iteritems
+from glances.globals import WINDOWS
+from glances.logger import logger
+from glances.processes import glances_processes
 from glances.plugins.glances_core import Plugin as CorePlugin
-from glances.core.glances_globals import is_windows
-from glances.core.glances_processes import glances_processes
 from glances.plugins.glances_plugin import GlancesPlugin
 
 
 def convert_timedelta(delta):
     """Convert timedelta to human-readable time."""
-    # Python 2.7+:
-    # total_seconds = delta.total_seconds()
-    # hours = total_seconds // 3600
     days, total_seconds = delta.days, delta.seconds
     hours = days * 24 + total_seconds // 3600
     minutes = (total_seconds % 3600) // 60
@@ -55,7 +51,7 @@ class Plugin(GlancesPlugin):
 
     def __init__(self, args=None):
         """Init the plugin."""
-        GlancesPlugin.__init__(self, args=args)
+        super(Plugin, self).__init__(args=args)
 
         # We want to display the stat in the curse interface
         self.display_curse = True
@@ -69,7 +65,7 @@ class Plugin(GlancesPlugin):
         except Exception:
             self.nb_log_core = 0
 
-        # Note: 'glances_processes' is already init in the glances_processes.py script
+        # Note: 'glances_processes' is already init in the processes.py script
 
     def get_key(self):
         """Return the key of the list."""
@@ -228,8 +224,8 @@ class Plugin(GlancesPlugin):
             if nice is None:
                 nice = '?'
             msg = '{0:>5}'.format(nice)
-            if isinstance(nice, int) and ((is_windows and nice != 32) or
-                                          (not is_windows and nice != 0)):
+            if isinstance(nice, int) and ((WINDOWS and nice != 32) or
+                                          (not WINDOWS and nice != 0)):
                 ret.append(self.curse_add_line(msg, decoration='NICE'))
             else:
                 ret.append(self.curse_add_line(msg))
@@ -294,27 +290,22 @@ class Plugin(GlancesPlugin):
         # If no command line for the process is available, fallback to
         # the bare process name instead
         cmdline = p['cmdline']
-        argument = ' '.join(cmdline.split()[1:])
         try:
-            if cmdline == '':
-                msg = ' {0}'.format(p['name'])
-                ret.append(self.curse_add_line(msg, splittable=True))
-            elif args.process_short_name:
-                msg = ' {0}'.format(p['name'])
-                ret.append(self.curse_add_line(msg, decoration='PROCESS', splittable=True))
-                msg = ' {0}'.format(argument)
-                ret.append(self.curse_add_line(msg, splittable=True))
-            else:
-                cmd = cmdline.split()[0]
-                path, basename = os.path.split(cmd)
-                if os.path.isdir(path):
+            # XXX: remove `cmdline != ['']` when we'll drop support for psutil<4.0.0
+            if cmdline and cmdline != ['']:
+                path, cmd = os.path.split(cmdline[0])
+                if os.path.isdir(path) and not args.process_short_name:
                     msg = ' {0}'.format(path) + os.sep
                     ret.append(self.curse_add_line(msg, splittable=True))
-                    ret.append(self.curse_add_line(basename, decoration='PROCESS', splittable=True))
+                    ret.append(self.curse_add_line(cmd, decoration='PROCESS', splittable=True))
                 else:
-                    msg = ' {0}'.format(basename)
+                    msg = ' {0}'.format(cmd)
                     ret.append(self.curse_add_line(msg, decoration='PROCESS', splittable=True))
-                msg = ' {0}'.format(argument)
+                arguments = ' '.join(cmdline[1:]).replace('\n', ' ')
+                msg = ' {0}'.format(arguments)
+                ret.append(self.curse_add_line(msg, splittable=True))
+            else:
+                msg = ' {0}'.format(p['name'])
                 ret.append(self.curse_add_line(msg, splittable=True))
         except UnicodeEncodeError:
             ret.append(self.curse_add_line('', splittable=True))
@@ -334,7 +325,7 @@ class Plugin(GlancesPlugin):
             if 'memory_info_ex' in p and p['memory_info_ex'] is not None:
                 ret.append(self.curse_new_line())
                 msg = xpad + 'Memory info: '
-                for k, v in p['memory_info_ex']._asdict().items():
+                for k, v in iteritems(p['memory_info_ex']._asdict()):
                     # Ignore rss and vms (already displayed)
                     if k not in ['rss', 'vms'] and v is not None:
                         msg += k + ' ' + self.auto_unit(v, low_precision=False) + ' '
@@ -365,7 +356,7 @@ class Plugin(GlancesPlugin):
                 v = p['ionice'].ioclass
                 # Linux: The scheduling class. 0 for none, 1 for real time, 2 for best-effort, 3 for idle.
                 # Windows: On Windows only ioclass is used and it can be set to 2 (normal), 1 (low) or 0 (very low).
-                if is_windows:
+                if WINDOWS:
                     if v == 0:
                         msg += k + 'Very Low'
                     elif v == 1:
@@ -421,7 +412,12 @@ class Plugin(GlancesPlugin):
                 # End of extended stats
                 first = False
             if glances_processes.process_filter is not None:
+                if args.reset_minmax_tag:
+                    args.reset_minmax_tag = not args.reset_minmax_tag
+                    self.__mmm_reset()
                 self.__msg_curse_sum(ret, args=args)
+                self.__msg_curse_sum(ret, mmm='min', args=args)
+                self.__msg_curse_sum(ret, mmm='max', args=args)
 
         # Return the message with decoration
         return ret
@@ -455,34 +451,45 @@ class Plugin(GlancesPlugin):
         ret.append(self.curse_add_line(msg))
         msg = '{0:>10}'.format('TIME+')
         ret.append(self.curse_add_line(msg, sort_style if process_sort_key == 'cpu_times' else 'DEFAULT', optional=True))
-        msg = '{0:>6}'.format('IOR/s')
+        msg = '{0:>6}'.format('R/s')
         ret.append(self.curse_add_line(msg, sort_style if process_sort_key == 'io_counters' else 'DEFAULT', optional=True, additional=True))
-        msg = '{0:>6}'.format('IOW/s')
+        msg = '{0:>6}'.format('W/s')
         ret.append(self.curse_add_line(msg, sort_style if process_sort_key == 'io_counters' else 'DEFAULT', optional=True, additional=True))
         msg = ' {0:8}'.format('Command')
         ret.append(self.curse_add_line(msg, sort_style if process_sort_key == 'name' else 'DEFAULT'))
 
-    def __msg_curse_sum(self, ret, sep_char='_', args=None):
+    def __msg_curse_sum(self, ret, sep_char='_', mmm=None, args=None):
         """
         Build the sum message (only when filter is on) and add it to the ret dict
+        * ret: list of string where the message is added
+        * sep_char: define the line separation char
+        * mmm: display min, max, mean or current (if mmm=None)
+        * args: Glances args
         """
         ret.append(self.curse_new_line())
-        ret.append(self.curse_add_line(sep_char * 70))
-        ret.append(self.curse_new_line())
+        if mmm is None:
+            ret.append(self.curse_add_line(sep_char * 69))
+            ret.append(self.curse_new_line())
         # CPU percent sum
-        msg = '{0:>6.1f}'.format(self.__sum_stats('cpu_percent'))
-        ret.append(self.curse_add_line(msg, decoration='FILTER'))
+        msg = '{0:>6.1f}'.format(self.__sum_stats('cpu_percent', mmm=mmm))
+        ret.append(self.curse_add_line(msg,
+                                       decoration=self.__mmm_deco(mmm)))
         # MEM percent sum
-        msg = '{0:>6.1f}'.format(self.__sum_stats('memory_percent'))
-        ret.append(self.curse_add_line(msg, decoration='FILTER'))
+        msg = '{0:>6.1f}'.format(self.__sum_stats('memory_percent', mmm=mmm))
+        ret.append(self.curse_add_line(msg,
+                                       decoration=self.__mmm_deco(mmm)))
         # VIRT and RES memory sum
         if 'memory_info' in self.stats[0] and self.stats[0]['memory_info'] is not None and self.stats[0]['memory_info'] != '':
             # VMS
-            msg = '{0:>6}'.format(self.auto_unit(self.__sum_stats('memory_info', 1), low_precision=False))
-            ret.append(self.curse_add_line(msg, decoration='FILTER', optional=True))
+            msg = '{0:>6}'.format(self.auto_unit(self.__sum_stats('memory_info', indice=1, mmm=mmm), low_precision=False))
+            ret.append(self.curse_add_line(msg,
+                                           decoration=self.__mmm_deco(mmm),
+                                           optional=True))
             # RSS
-            msg = '{0:>6}'.format(self.auto_unit(self.__sum_stats('memory_info', 0), low_precision=False))
-            ret.append(self.curse_add_line(msg, decoration='FILTER', optional=True))
+            msg = '{0:>6}'.format(self.auto_unit(self.__sum_stats('memory_info', indice=0, mmm=mmm), low_precision=False))
+            ret.append(self.curse_add_line(msg,
+                                           decoration=self.__mmm_deco(mmm),
+                                           optional=True))
         else:
             msg = '{0:>6}'.format('')
             ret.append(self.curse_add_line(msg))
@@ -503,37 +510,97 @@ class Plugin(GlancesPlugin):
         msg = '{0:>10}'.format('')
         ret.append(self.curse_add_line(msg, optional=True))
         # IO read/write
-        if 'io_counters' in self.stats[0]:
+        if 'io_counters' in self.stats[0] and mmm is None:
             # IO read
-            io_rs = int((self.__sum_stats('io_counters', 0) - self.__sum_stats('io_counters', 2)) / self.stats[0]['time_since_update'])
+            io_rs = int((self.__sum_stats('io_counters', 0) - self.__sum_stats('io_counters', indice=2, mmm=mmm)) / self.stats[0]['time_since_update'])
             if io_rs == 0:
                 msg = '{0:>6}'.format('0')
             else:
                 msg = '{0:>6}'.format(self.auto_unit(io_rs, low_precision=True))
-            ret.append(self.curse_add_line(msg, decoration='FILTER', optional=True, additional=True))
+            ret.append(self.curse_add_line(msg,
+                                           decoration=self.__mmm_deco(mmm),
+                                           optional=True, additional=True))
             # IO write
-            io_ws = int((self.__sum_stats('io_counters', 1) - self.__sum_stats('io_counters', 3)) / self.stats[0]['time_since_update'])
+            io_ws = int((self.__sum_stats('io_counters', 1) - self.__sum_stats('io_counters', indice=3, mmm=mmm)) / self.stats[0]['time_since_update'])
             if io_ws == 0:
                 msg = '{0:>6}'.format('0')
             else:
                 msg = '{0:>6}'.format(self.auto_unit(io_ws, low_precision=True))
-            ret.append(self.curse_add_line(msg, decoration='FILTER', optional=True, additional=True))
+            ret.append(self.curse_add_line(msg,
+                                           decoration=self.__mmm_deco(mmm),
+                                           optional=True, additional=True))
         else:
             msg = '{0:>6}'.format('')
             ret.append(self.curse_add_line(msg, optional=True, additional=True))
             ret.append(self.curse_add_line(msg, optional=True, additional=True))
+        if mmm is None:
+            msg = ' < {0}'.format('current')
+            ret.append(self.curse_add_line(msg, optional=True))
+        else:
+            msg = ' < {0}'.format(mmm)
+            ret.append(self.curse_add_line(msg, optional=True))
+            msg = ' (\'M\' to reset)'
+            ret.append(self.curse_add_line(msg, optional=True))
 
-    def __sum_stats(self, key, indice=None):
+    def __mmm_deco(self, mmm):
+        """
+        Return the decoration string for the current mmm status
+        """
+        if mmm is not None:
+            return 'DEFAULT'
+        else:
+            return 'FILTER'
+
+    def __mmm_reset(self):
+        """
+        Reset the MMM stats
+        """
+        self.mmm_min = {}
+        self.mmm_max = {}
+
+    def __sum_stats(self, key, indice=None, mmm=None):
         """
         Return the sum of the stats value for the given key
-        If indice is given, get the p[key][indice]
+        * indice: If indice is set, get the p[key][indice]
+        * mmm: display min, max, mean or current (if mmm=None)
         """
+        # Compute stats summary
         ret = 0
         for p in self.stats:
             if indice is None:
                 ret += p[key]
             else:
                 ret += p[key][indice]
+
+        # Manage Min/Max/Mean
+        mmm_key = self.__mmm_key(key, indice)
+        if mmm == 'min':
+            try:
+                if self.mmm_min[mmm_key] > ret:
+                    self.mmm_min[mmm_key] = ret
+            except AttributeError:
+                self.mmm_min = {}
+                return 0
+            except KeyError:
+                self.mmm_min[mmm_key] = ret
+            ret = self.mmm_min[mmm_key]
+        elif mmm == 'max':
+            try:
+                if self.mmm_max[mmm_key] < ret:
+                    self.mmm_max[mmm_key] = ret
+            except AttributeError:
+                self.mmm_max = {}
+                return 0
+            except KeyError:
+                self.mmm_max[mmm_key] = ret
+            ret = self.mmm_max[mmm_key]
+
+        return ret
+
+    def __mmm_key(self, key, indice):
+        ret = key
+        if indice is not None:
+            ret += str(indice)
         return ret
 
     def sort_stats(self, sortedby=None):
